#include <fstream>
#include "fitnessdoc.h"

FitnessDoc::FitnessDoc()
{
	_modified = FALSE;
}

FitnessDoc::~FitnessDoc()
{
	// nothing yet
}

void FitnessDoc::newDoc()
{
	_name = _id = QString::null;
	_available = _total = 0;
	_items.clear();
	_filename = QString::null;
	_modified = FALSE;
	emit documentChanged(this);
}

bool FitnessDoc::save()
{
	std::ofstream file(_filename);
	if ( !file.fail() )
	{
		file << _id.utf8() << std::endl;
		file<< _name.utf8() << std::endl;
		file << _available << std::endl;
		file << _items.count() << std::endl;
		for (FitnessItem *i= _items.first(); i; i=_items.next())
		{
			file << i->date().toString(Qt::ISODate)  << std::endl;
			file << i->service().utf8() << std::endl;
			file << i->prise() << std::endl;
		}
		_modified = FALSE;
		return TRUE;
	}
	else
	{
		return FALSE;
	}
}

bool FitnessDoc::saveAs(const QString & fname)
{
	_filename=fname;
	return save();
}

bool FitnessDoc::load(const QString & fname)
{
	_total = 0;
	std::ifstream file;
	char buffer[1024];
	file.open(fname);
	if ( !file.fail() )
	{
		int itemCount;
		file.getline(buffer,1024); _id = QString::fromUtf8(buffer);
		file.getline(buffer,1024); _name = QString::fromUtf8(buffer);
		file >> _available;
		file.getline(buffer,1024);
		_items.clear();
		file >> itemCount;
		file.getline(buffer,1024); //skip rest of line
		while ( (itemCount > 0) && !file.eof() ) 
		{
			file.getline(buffer,1024);
			QDate date = QDate::fromString(QString::fromUtf8(buffer), Qt::ISODate);
			file.getline(buffer,1024);
			QString service = QString::fromUtf8(buffer);
			int prise;
			file >> prise;
			_total += prise;
			file.getline(buffer,1024); //skip rest of line
			FitnessItem *i=new FitnessItem(service, prise, date);
			_items.append(i);
			itemCount--;
		}
		_filename=fname;
		emit documentChanged(this);
		_modified = FALSE;
		return TRUE;
	}
	else
	{
		return FALSE;
	}
}

bool FitnessDoc::isModified() const
{
	return _modified;
}

const char* FitnessDoc::check()
{
	if ( _id.isEmpty() )
	{
		return "The document cannot be saved \n until an ID number is specified.";
	}
	else if ( _name.isEmpty() )
	{
		return "The document cannot be saved \n until the _name is specified.";
	}
	else
	{
		return 0;
	}
}
