#ifndef FITNESSDOC_H
#define FITNESSDOC_H

#include <qobject.h>
#include <qptrlist.h>
#include <qdatetime.h>

class FitnessItem
{
	public:
	
		FitnessItem(QString s=QString::null, int p=0, QDate d=QDate::currentDate()):  _service(s),  _prise(p),  _date(d)  {}
		void update(QString s=QString::null, int p=0, QDate d=QDate::currentDate())
		{
			_service=s;
			_prise=p;
			_date=d;
		}
	
		const QString& service() { return _service; }
		const QDate& date() { return _date; }
		const int prise() { return _prise; }

	protected:
	
		QString _service;
		int _prise;
		QDate _date;
};



class FitnessDoc : public QObject
{
	Q_OBJECT

	public:
		FitnessDoc();
		~FitnessDoc();
		void newDoc();
		bool save();
		bool saveAs(const QString &filename);
		bool load(const QString &filename);
		bool isModified() const;
		void setModified(bool val=TRUE) { if (_modified = val) emit documentChanged(this); }
		
		const QString id() const { return _id; }
		const QString name() const { return _name; }
		const int available() const { return _available; }
		const int total() const { return _total; }
		
		const QPtrList<FitnessItem>& items() const { return _items; }
		const QString fileName() const { return _filename; }
		const char* check();
			
		void insertItem(FitnessItem *i)
		{
			_available -= i->prise();
			_total += i->prise();
			_items.append(i);
			_modified=TRUE;
			emit itemInserted(i);
		}
		
		void removeItem(FitnessItem *i)
		{
			bool found = FALSE;
			FitnessItem *ii= _items.first();
			for (; ii && !found; ii=!found?_items.next():ii )
			{
				found = ( (i->prise() == ii->prise()) && (i->service() == ii->service()) && (i->date() == ii->date()) );
			}
			if (found)
			{
				if (_items.remove(ii))
				{
					_available += ii->prise();
					_total -= ii->prise();
					setModified();
				}
			}
		} 
		
		void updateItem(FitnessItem *i, FitnessItem* j)
		{
			bool found = FALSE;
			FitnessItem *ii= _items.first();
			for (; ii && !found; ii=!found?_items.next():ii)
			{
				found = ( (i->prise() == ii->prise()) && (i->service() == ii->service()) && (i->date() == ii->date()) );
			}
			if (found)
			{
				if (_items.replace(_items.find(ii), j))
				{
					_available += i->prise() - j->prise();
					_total += j->prise() - i->prise();
					setModified();
				}
			}
		}
	
	signals:
		void documentChanged(FitnessDoc* doc);
		void itemInserted(FitnessItem *i);
	
	public slots:
		void setId(const QString &txt) { _id=txt; setModified(); }
		void setName(const QString &txt) { _name=txt; setModified(); }
		void setAvailable(const int &num) { _available=num; setModified(); }
		
	protected:
		QString _name;
		QString _id;
		int _available;
		int _total;
		
		bool _modified;
		QPtrList<FitnessItem> _items;
		QString _filename;

};

#endif


