/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
** These will automatically be called by the form's constructor and
** destructor.
*****************************************************************************/

#include "itemdialog.h"
#include "payindialog.h"
#include "serviceform.h"
#include "statisticsform.h"
#include "statisticspainter.h"
#include "fitnessdoc.h"
#include "qdatetime.h"
#include <qmsgbox.h>
#include <qvalidator.h>
#include <qfiledialog.h>
#include <qcombobox.h>
#include <fstream>

FitnessDoc doc;

void mainForm::fileExit()
{
	if ( doc.isModified() )
	{
		int query = querySave();
		if  ( query == QMessageBox::Yes )
		{
			fileSave();
			this->close();
		}
		else if ( query == QMessageBox::No )
		{
			this->close();
		}
	}
	else
	{
		if ( queryExit() )
		{
			this->close();
		}
	}
};


void mainForm::fileOpen()
{
	int query = QMessageBox::No;
	if ( doc.isModified() )
	{
		query = querySave();
		if  ( query == QMessageBox::Yes )
		{
			fileSave();
		}
	}
	if ( query == QMessageBox::No )
	{
		QString fn = QFileDialog::getOpenFileName(0,0,this);
		if ( !fn.isEmpty() )
		{
			if ( doc.load(fn) )
			{
				refreshAll();
			}
			else
			{
				QMessageBox::information( this, tr("Error"), "File I/O error", QMessageBox::Ok );
			}
		}
		else
		{
			QMessageBox::information( this, tr("Error"), "File does not exist", QMessageBox::Ok );
		}
	}
};


void mainForm::fileSave()
{
	doc.setId(idEdit->text());
	doc.setName(nameEdit->text());
	if ( doc.fileName() != QString::null )
	{
		QString error = doc.check();
		if ( error.isEmpty() )
		{
			if ( doc.save() )
			{
				// success
			}
			else
			{
				QMessageBox::information( this, tr("Error"), "File I/O error", QMessageBox::Ok );
			}
		}
		else
		{
			QMessageBox::information( this, tr("Warning"), error, QMessageBox::Ok );
		}
	}
	else
	{
		fileSaveAs();
	}
};


void mainForm::fileSaveAs()
{
	QString error = doc.check();
	if ( error == 0 )
	{
		QString fn = QFileDialog::getSaveFileName(0, 0, this);
		if ( !fn.isEmpty() )
		{
			if ( doc.saveAs(fn) )
			{
				// success
			}
			else
			{
				QMessageBox::information( this, tr("Error"), "File I/O error", QMessageBox::Ok );
			}
		}
	}
	else
	{
		QMessageBox::information( this, tr("Warning"), error, QMessageBox::Ok );
	}
};

void mainForm::fileNew()
{
	int query = QMessageBox::No;
	if ( doc.isModified() )
	{
		query = querySave();
		if  ( query == QMessageBox::Yes )
		{
			fileSave();
		}
	}
	if ( query == QMessageBox::No )
	{
		doc.newDoc();
		refreshAll();
	}
};


void mainForm::helpAbout()
{
	QMessageBox::about( this, tr("About..."), tr("\n\n\nFITNESS CENTER Version 1.0 \nby Kroly Pfaff") );
};


void mainForm::openPayin()
{
	payinDialog* dialog = new payinDialog(this, 0, true);
	QIntValidator v(dialog, 0);
	dialog->payinEdit->setValidator(&v);
	if (dialog->exec())
	{
		int increase = dialog->payinEdit->text().toInt();
		if ( increase > 0 )
		{
			doc.setAvailable(increase + availableEdit->text().toInt());
			updateTexts();
		}
		else
		{
			QMessageBox::information( this, tr("Error"), "You have to give a positive number", QMessageBox::Ok );
		}
	}
	delete dialog;
};


void mainForm::openStatistics()
{
	statisticsForm* form = new statisticsForm(this, 0, true);
	form->paint(doc);
	form->show();
};


int mainForm::querySave()
{
	int verifySave = QMessageBox::warning ( this, tr("Save form"), tr("Save changes to actual form?"), QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel );
	return verifySave;
};


bool mainForm::queryExit()
{
	int verifyExit = QMessageBox::information ( this, tr("Exit..."), tr("Do you really want to exit?"), QMessageBox::Yes, QMessageBox::Cancel );
	return ( verifyExit == QMessageBox::Yes );
};


void mainForm::servicesDelete()
{
	QListViewItem* item = serviceList->currentItem();
	QDate today = QDate::currentDate();
	if ( item && (QDate::fromString(item->text(0), Qt::ISODate) == today) )
	{
		doc.removeItem(new FitnessItem(item->text(1), item->text(2).toInt(), today));
		serviceList->takeItem(item);
		updateTexts();
	}
	else
	{
		QMessageBox::information( this, tr("Error"), "Only today's services can be deleted", QMessageBox::Ok );
	}
};


void mainForm::servicesEdit()
{
	QListViewItem* item = serviceList->currentItem();
	QDate today = QDate::currentDate();
	if ( item && (QDate::fromString(item->text(0), Qt::ISODate) == today) )
	{
		itemDialog* dialog = new itemDialog(this, 0, true);
		QIntValidator v(dialog, 0);
		dialog->priseEdit->setValidator(&v);
		dialog->priseEdit->setText(item->text(2));
		int index = dialog->serviceCombo->currentItem();
		while ( dialog->serviceCombo->text(index) != item->text(1) )
		{
			index++;
		}
		dialog->serviceCombo->setCurrentItem(index);
		if (dialog->exec())
		{
			QString service = dialog->serviceCombo->currentText();
			QString prise = dialog->priseEdit->text();
			doc.updateItem(new FitnessItem(item->text(1), item->text(2).toInt(), today), new FitnessItem(service, prise.toInt(), today));
			item->setText( 1, service );
			item->setText( 2, prise );
			updateTexts();
		}
	}
	else
	{
		QMessageBox::information( this, tr("Error"), "Only today's services can be edited", QMessageBox::Ok );
	}
};


void mainForm::servicesManage()
{
	serviceForm* form = new serviceForm(this, 0, true);
	form->show();
};

 
void mainForm::servicesUse()
{
	itemDialog* dialog = new itemDialog(this, 0, true);
	QIntValidator v(dialog, 0);
	dialog->priseEdit->setValidator(&v);
	if (dialog->exec())
	{
		QString prise = dialog->priseEdit->text();
		if (prise.toInt() <= doc.available() * 1.1 )
		{
			QDate today = QDate::currentDate();
			QString service = dialog->serviceCombo->currentText();
			doc.insertItem(new FitnessItem(service, prise.toInt(), today));
			QListViewItem* item = new QListViewItem( serviceList, 0 );
			item->setText( 0, today.toString(Qt::ISODate) );
			item->setText( 1, service );
			item->setText( 2, prise );
			updateTexts();
		}
		else
		{
			QMessageBox::information( this, tr("Error"), "No money available for this service", QMessageBox::Ok );
		}
	}
};


void mainForm::textModified()
{
	doc.setModified();
};


void mainForm::updateTexts()
{
	availableEdit->setText(QString::number(doc.available()));
	totalText->setText(QString::number(doc.total()));
}


void mainForm::refreshAll()
{
	updateTexts();
	idEdit->setText(doc.id());
	nameEdit->setText(doc.name());
	serviceList->clear();
	QListIterator<FitnessItem> it (doc.items());
	for (; it.current(); ++it)
	{
		QListViewItem* item = new QListViewItem( serviceList, 0 );
		item->setText( 0, it.current()->date().toString(Qt::ISODate) );
		item->setText( 1, it.current()->service() );
		item->setText( 2, QString::number(it.current()->prise()) );
	}
}
